﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Net.Http;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;
using System.Xml.Linq;

namespace Library
{
    public class ViewModel : INotifyPropertyChanged
    {
        private const string filename = "handle.txt";

        private IFileService fileService;

        public ViewModel(IFileService fileService)
        {
            this.fileService = fileService;

            GetTweetCommand = new RelayCommand(async () => await OnGetTweetAsync());

            Initialize();
        }

        private async void Initialize()
        {
            TwitterHandle = await fileService.LoadStringAsync(filename);
        }

        private string twitterHandle;
        public string TwitterHandle
        {
            get
            {
                return twitterHandle;
            }
            set
            {
                if (tweetText == value)
                    return;

                twitterHandle = value;
                RaisePropertyChanged();
                fileService.SaveStringAsync(filename, value);
            }
        }

        private string tweetText;
        public string TweetText
        {
            get
            {
                return tweetText;
            }
            private set
            {
                if (tweetText == value)
                    return;

                tweetText = value;
                RaisePropertyChanged();
            }
        }

        public ICommand GetTweetCommand { get; private set; }

        private async Task OnGetTweetAsync()
        {
            var model = new Model();
            TweetText = await model.GetLastTweetAsync(TwitterHandle);
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void RaisePropertyChanged([CallerMemberName] string propertyName = null)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
